@@ -3,6 +3,7 @@ import sys
 import math
 import random
 import time
+import os.path
 
 from collections import deque
 from pyglet import image
@@ -75,8 +76,7 @@ def tex_coords(top, bottom, side):
     result.extend(side * 4)
     return result
 
-
-TEXTURE_PATH = 'texture.png'
+TEXTURE_PATH = os.path.join(os.path.split(__file__)[0], 'texture.png')
 
 GRASS = tex_coords((1, 0), (0, 1), (0, 0))
 SAND = tex_coords((1, 1), (1, 1), (1, 1))
@@ -865,15 +865,16 @@ class Window(pyglet.window.Window):
 
 
 class World:
-    MATERIALS = {
+    _MAT = {
         'default:brick': BRICK,
         'default:sand': SAND,
         'default:stone': STONE,
         'default:grass': GRASS,
         'air': AIR
     }
+    MATERIALS = list(_MAT.keys())
 
-    def __init__(self, name):
+    def __init__(self, name="PyBlockWorld"):
         self.window = Window(width=800, height=600, 
             caption=name, resizable=True)
         self.window.unknown_key_pressed = self.__build_key_function
@@ -891,7 +892,7 @@ class World:
             if pos in self.window.model.world:
                 self.window.model.remove_block(pos)
         else:
-            self.window.model.add_block(pos, World.MATERIALS[blocktype])
+            self.window.model.add_block(pos, World._MAT[blocktype])
 
     def setBlocks(self, x1, y1, z1, x2,y2,z2, blocktype):
         xmin, ymin, zmin = min(x1,x2), min(y1,y2), min(z1,z2)
@@ -953,11 +954,11 @@ def setup():
 def main():
     def b_key_pressed(world:World):
         print("b pressed. player at", world.player_position())
-        x,y,z = world.player_postion()
+        x,y,z = world.player_position()
         world.setBlock(x,y,z, "default:brick")
         
-    world = World("DEMO")
-    print("Block types", World.MATERIALS.keys())
+    world = World("DEMO WORLD")
+    print("Block types", World.MATERIALS)
     world.build_key_function = b_key_pressed
     world.run()
     
